@@ -357,6 +357,11 @@ void spg_free_dataset(SpglibDataset *dataset)
     dataset->n_std_atoms = 0;
   }
 
+  if (dataset->site_symmetry_symbols != NULL) {
+    free(dataset->site_symmetry_symbols);
+    dataset->site_symmetry_symbols = NULL;
+  }
+
   dataset->spacegroup_number = 0;
   dataset->hall_number = 0;
   strcpy(dataset->international_symbol, "");
@@ -471,23 +476,37 @@ int spg_get_hall_number_from_symmetry(SPGCONST int rotation[][3][3],
 
   symmetry = NULL;
   prim_symmetry = NULL;
+  hall_number = 0;
+
+  if ((symmetry = sym_alloc_symmetry(num_operations)) == NULL) {
+    return 0;
+  }
 
-  symmetry = sym_alloc_symmetry(num_operations);
   for (i = 0; i < num_operations; i++) {
     mat_copy_matrix_i3(symmetry->rot[i], rotation[i]);
     mat_copy_vector_d3(symmetry->trans[i], translation[i]);
   }
 
   prim_symmetry = prm_get_primitive_symmetry(symmetry, symprec);
+  sym_free_symmetry(symmetry);
+  symmetry = NULL;
+
+  if (prim_symmetry == NULL) {
+    return 0;
+  }
+
   hall_number = spa_search_spacegroup_with_symmetry(prim_symmetry, symprec);
 
   if (hall_number) {
     spglib_error_code = SPGLIB_SUCCESS;
-    return hall_number;
   } else {
     spglib_error_code = SPGERR_SPACEGROUP_SEARCH_FAILED;
-    return 0;
   }
+
+  sym_free_symmetry(prim_symmetry);
+  prim_symmetry = NULL;
+
+  return hall_number;
 }
 
 /* Return 0 if failed */
@@ -968,128 +987,36 @@ size_t spg_get_dense_stabilized_reciprocal_mesh(int grid_address[][3],
                                               qpoints);
 }
 
-int spg_get_grid_points_by_rotations(int rot_grid_points[],
-                                     const int address_orig[3],
-                                     const int num_rot,
-                                     SPGCONST int rot_reciprocal[][3][3],
-                                     const int mesh[3],
-                                     const int is_shift[3])
+void spg_get_dense_grid_points_by_rotations(size_t rot_grid_points[],
+                                            const int address_orig[3],
+                                            const int num_rot,
+                                            SPGCONST int rot_reciprocal[][3][3],
+                                            const int mesh[3],
+                                            const int is_shift[3])
 {
-  int i;
-  MatINT *rot;
-
-  rot = NULL;
-
-  if ((rot = mat_alloc_MatINT(num_rot)) == NULL) {
-    return 0;
-  }
-
-  for (i = 0; i < num_rot; i++) {
-    mat_copy_matrix_i3(rot->mat[i], rot_reciprocal[i]);
-  }
-  kpt_get_grid_points_by_rotations(rot_grid_points,
-                                   address_orig,
-                                   rot,
-                                   mesh,
-                                   is_shift);
-  mat_free_MatINT(rot);
-  rot = NULL;
-
-  return 1;
-}
-
-int spg_get_dense_grid_points_by_rotations(size_t rot_grid_points[],
-                                           const int address_orig[3],
-                                           const int num_rot,
-                                           SPGCONST int rot_reciprocal[][3][3],
-                                           const int mesh[3],
-                                           const int is_shift[3])
-{
-  int i;
-  MatINT *rot;
-
-  rot = NULL;
-
-  if ((rot = mat_alloc_MatINT(num_rot)) == NULL) {
-    return 0;
-  }
-
-  for (i = 0; i < num_rot; i++) {
-    mat_copy_matrix_i3(rot->mat[i], rot_reciprocal[i]);
-  }
   kpt_get_dense_grid_points_by_rotations(rot_grid_points,
                                          address_orig,
-                                         rot,
+                                         rot_reciprocal,
+                                         num_rot,
                                          mesh,
                                          is_shift);
-  mat_free_MatINT(rot);
-  rot = NULL;
-
-  return 1;
 }
 
-int spg_get_BZ_grid_points_by_rotations(int rot_grid_points[],
-                                        const int address_orig[3],
-                                        const int num_rot,
-                                        SPGCONST int rot_reciprocal[][3][3],
-                                        const int mesh[3],
-                                        const int is_shift[3],
-                                        const int bz_map[])
+void spg_get_dense_BZ_grid_points_by_rotations(size_t rot_grid_points[],
+                                               const int address_orig[3],
+                                               const int num_rot,
+                                               SPGCONST int rot_reciprocal[][3][3],
+                                               const int mesh[3],
+                                               const int is_shift[3],
+                                               const size_t bz_map[])
 {
-  int i;
-  MatINT *rot;
-
-  rot = NULL;
-
-  if ((rot = mat_alloc_MatINT(num_rot)) == NULL) {
-    return 0;
-  }
-
-  for (i = 0; i < num_rot; i++) {
-    mat_copy_matrix_i3(rot->mat[i], rot_reciprocal[i]);
-  }
-  kpt_get_BZ_grid_points_by_rotations(rot_grid_points,
-                                      address_orig,
-                                      rot,
-                                      mesh,
-                                      is_shift,
-                                      bz_map);
-  mat_free_MatINT(rot);
-  rot = NULL;
-
-  return 1;
-}
-
-int spg_get_dense_BZ_grid_points_by_rotations(size_t rot_grid_points[],
-                                              const int address_orig[3],
-                                              const int num_rot,
-                                              SPGCONST int rot_reciprocal[][3][3],
-                                              const int mesh[3],
-                                              const int is_shift[3],
-                                              const size_t bz_map[])
-{
-  int i;
-  MatINT *rot;
-
-  rot = NULL;
-
-  if ((rot = mat_alloc_MatINT(num_rot)) == NULL) {
-    return 0;
-  }
-
-  for (i = 0; i < num_rot; i++) {
-    mat_copy_matrix_i3(rot->mat[i], rot_reciprocal[i]);
-  }
   kpt_get_dense_BZ_grid_points_by_rotations(rot_grid_points,
                                             address_orig,
-                                            rot,
+                                            rot_reciprocal,
+                                            num_rot,
                                             mesh,
                                             is_shift,
                                             bz_map);
-  mat_free_MatINT(rot);
-  rot = NULL;
-
-  return 1;
 }
 
 int spg_relocate_BZ_grid_address(int bz_grid_address[][3],
